@@ -5,4 +5,6 @@
 from .four_chan.four_chan import *
 from .rss.rss_feed import RSSFeed
 
+# from .translator.deps import TranslateFiles, AvailableLangs, ExtractText
 
+from .translator.deps import *
